Learn R Programming

sphunif (version 1.4.3)

Sobolev_coefs: Transformation between different coefficients in Sobolev statistics

Description

Given a Sobolev statistic $$S_{n, p} = \sum_{i, j = 1}^n \psi(\cos^{-1}({\bf X}_i'{\bf X}_j)),$$ for a sample \({\bf X}_1, \ldots, {\bf X}_n \in S^{p - 1} := \{{\bf x} \in R^p : ||{\bf x}|| = 1\}\), \(p\ge 2\), three important sequences are related to \(S_{n, p}\).

  • Gegenbauer coefficients \(\{b_{k, p}\}\) of \(\psi_p\) (see, e.g., the projected-ecdf statistics), given by $$b_{k, p} := \frac{1}{c_{k, p}}\int_0^\pi \psi_p(\theta) C_k^{p / 2 - 1}(\cos\theta)\,\mathrm{d}\theta.$$

  • Weights \(\{v_{k, p}^2\}\) of the asymptotic distribution of the Sobolev statistic, \(\sum_{k = 1}^\infty v_k^2 \chi^2_{d_{p, k}}\), given by $$v_{k, p}^2 = \left(1 + \frac{2k}{p - 2}\right)^{-1} b_{k, p}, \quad p \ge 3.$$

  • Gegenbauer coefficients \(\{u_{k, p}\}\) of the local projected alternative associated to \(S_{n, p}\), given by $$u_{k, p} = \left(1 + \frac{2k}{p - 2}\right) v_{k, p}, \quad p \ge 3.$$

For \(p = 2\), the factor \((1 + 2k / (p - 2))\) is replaced by \(2\).

Usage

bk_to_vk2(bk, p, log = FALSE)

bk_to_uk(bk, p, signs = 1)

vk2_to_bk(vk2, p, log = FALSE)

vk2_to_uk(vk2, p, signs = 1)

uk_to_vk2(uk, p)

uk_to_bk(uk, p)

Value

The corresponding vectors of coefficients vk2, bk, or uk, depending on the call.

Arguments

bk

coefficients \(b_{k, p}\) associated to the indexes 1:length(bk), a vector.

p

integer giving the dimension of the ambient space \(R^p\) that contains \(S^{p-1}\).

log

do operations in log scale (log-in, log-out)? Defaults to FALSE.

signs

signs of the coefficients \(u_{k, p}\), a vector of the same size as vk2 or bk, or a scalar. Defaults to 1.

vk2

squared coefficients \(v_{k, p}^2\) associated to the indexes 1:length(vk2), a vector.

uk

coefficients \(u_{k, p}\) associated to the indexes 1:length(uk), a vector.

Details

See more details in Prentice (1978) and García-Portugués et al. (2023). The appropriate signs of uk for the "PRt" Rothman test can be retrieved with akx and sqr = TRUE, see the examples.

References

García-Portugués, E., Navarro-Esteban, P., Cuesta-Albertos, J. A. (2023) On a projection-based class of uniformity tests on the hypersphere. Bernoulli, 29(1):181--204. tools:::Rd_expr_doi("10.3150/21-BEJ1454")

Prentice, M. J. (1978). On invariant tests of uniformity for directions and orientations. The Annals of Statistics, 6(1):169--176. tools:::Rd_expr_doi("10.1214/aos/1176344075")

Examples

Run this code
# bk, vk2, and uk for the PCvM test in p = 3
(bk <- Gegen_coefs_Pn(k = 1:5, type = "PCvM", p = 3))
(vk2 <- bk_to_vk2(bk = bk, p = 3))
(uk <- bk_to_uk(bk = bk, p = 3))

# vk2 is the same as
weights_dfs_Sobolev(K_max = 10, thre = 0, p = 3, type = "PCvM")$weights

# bk and uk for the Rothman test in p = 3, with adequate signs
t <- 1 / 3
(bk <- Gegen_coefs_Pn(k = 1:5, type = "PRt", p = 3, Rothman_t = t))
(ak <- akx(x = drop(q_proj_unif(t, p = 3)), p = 3, k = 1:5, sqr = TRUE))
(uk <- bk_to_uk(bk = bk, p = 3, signs = ak))

Run the code above in your browser using DataLab