Learn R Programming

sphunif (version 1.4.3)

avail_tests: Available circular and (hyper)spherical uniformity tests

Description

List of the tests implemented in the sphunif package.

Usage

avail_cir_tests

avail_sph_tests

Arguments

Value

A character vector whose elements are valid inputs for the type argument in unif_test, unif_stat, unif_stat_distr, and unif_stat_MC. avail_cir_tests provides the available circular tests and avail_sph_tests the (hyper)spherical tests.

Format

An object of class character of length 34.

An object of class character of length 19.

Examples

Run this code
# Circular tests
avail_cir_tests

# Spherical tests
avail_sph_tests

Run the code above in your browser using DataLab