Learn R Programming

sphunif (version 1.4.3)

chisq: Density and distribution of a chi squared

Description

Computation of the density and distribution functions of a chi squared.

Usage

d_chisq(x, df, ncp = 0L)

p_chisq(x, df, ncp = 0L)

Value

A matrix of size c(nx, 1) with the evaluation of the density or distribution function at x.

Arguments

x

a vector of size nx or a matrix of size c(nx, 1).

df

degrees of freedom.

ncp

non-centrality parameter.