Learn R Programming

sphunif (version 1.4.3)

r_unif: Sample uniformly distributed circular and spherical data

Description

Simulation of the uniform distribution on \([0, 2\pi)\) and \(S^{p-1}:=\{{\bf x}\in R^p:||{\bf x}||=1\}\), \(p\ge 2\).

Usage

r_unif_cir(n, M = 1L, sorted = FALSE)

r_unif_sph(n, p, M = 1L)

Value

  • r_unif_cir: a matrix of size c(n, M) with M random samples of size n of uniformly-generated circular data on \([0, 2\pi)\).

  • r_unif_sph: an array of size c(n, p, M) with M random samples of size n of uniformly-generated directions on \(S^{p-1}\).

Arguments

n

sample size.

M

number of samples of size n. Defaults to 1.

sorted

return each circular sample sorted? Defaults to FALSE.

p

integer giving the dimension of the ambient space \(R^p\) that contains \(S^{p-1}\).

Examples

Run this code
# A sample on [0, 2*pi)
n <- 5
r_unif_cir(n = n)

# A sample on S^1
p <- 2
samp <- r_unif_sph(n = n, p = p)
samp
rowSums(samp^2)

# A sample on S^2
p <- 3
samp <- r_unif_sph(n = n, p = p)
samp
rowSums(samp^2)

Run the code above in your browser using DataLab