Computes the finite Sobolev statistic $$ S_{n, p}(\{b_{k, p}\}_{k=1}^K) = \sum_{i, j = 1}^n \sum_{k = 1}^K b_{k, p}C_k^(p / 2 - 1)(\cos^{-1}({\bf X}_i'{\bf X}_j)),$$ for a sequence \(\{b_{k, p}\}_{k = 1}^K\) of non-negative weights. For \(p = 2\), the Gegenbauer polynomials are replaced by Chebyshev ones.
sph_stat_Sobolev(X, Psi_in_X = FALSE, p = 0, vk2 = c(0, 0, 1))cir_stat_Sobolev(Theta, Psi_in_Theta = FALSE, vk2 = c(0, 0, 1))
A matrix of size c(M, ncol(vk2)) containing the statistics for
each of the M samples.
an array of size c(n, p, M) containing the Cartesian
coordinates of M samples of size n of directions on
\(S^{p-1}\). Must not contain NA's.
does X contain the shortest angles matrix
\(\boldsymbol\Psi\) that is obtained with Psi_mat(X)?
If FALSE (default), \(\boldsymbol\Psi\) is computed
internally.
integer giving the dimension of the ambient space \(R^p\) that contains \(S^{p-1}\).
weights for the finite Sobolev test. A non-negative vector or
matrix. Defaults to c(0, 0, 1).
a matrix of size c(n, M) with M samples
of size n of circular data on \([0, 2\pi)\). Must not contain
NA's.
does Theta contain the shortest angles matrix
\(\boldsymbol\Psi\) that is obtained with
Psi_mat(array(Theta, dim = c(n, 1, M)))? If FALSE
(default), \(\boldsymbol\Psi\) is computed internally.