sort_each_col: Sort the columns of a matrix
Description
Convenience functions to sort the columns of a matrix in an
increasing way.
Usage
sort_each_col(A)sort_index_each_col(A)
Value
A matrix with the same dimensions as A such that each
column is sorted increasingly (for sort_each_col) or contains the
sorting indexes (for sort_index_each_col).
sort_index_each_col.
Arguments
- A
a matrix of arbitrary dimensions.